#
# spec file for package screencast
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.github.artemanufrij.screencast
Name:           screencast
Version:        1.0.0
Release:        3.4
Summary:        A screencasting application
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            https://github.com/artemanufrij/screencast
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(appindicator3-0.1)
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libwnck-3.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xtst)
Recommends:     gstreamer-plugins-base
Recommends:     gstreamer-plugins-good
Recommends:     gstreamer-plugins-ugly
Provides:       eidete = %{version}
Obsoletes:      eidete < %{version}

%description
A screencasting application for the Pantheon Desktop.

Current features:
  * encoding to WebM
  * selection of the area to be recorded
  * display of the pressed keys
  * audio recording

%lang_package

%prep
%autosetup

install -m0644 debian/copyright COPYING

%build
export CFLAGS="%{optflags} -Wno-implicit-function-declaration"
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}

%files
%license COPYING
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/metainfo/%{appid}.appdata.xml
%dir %{_datadir}/icons/hicolor/{128x128@2,128x128@2/apps,32x32@2,32x32@2/apps,48x48@2,48x48@2/apps,64x64@2,64x64@2/apps}

%files lang -f %{appid}.lang

%changelog
* Sun Nov 24 2024 Richard Rahl <rrahl0@opensuse.org>
- fix build by using CFLAGS="-Wno-implicit-function-declaration"
- update spec file for Leap 16.0:
  * remove %%suse_update_desktop_file
  * remove recommending lang package
  * use autosetup
  * remove HiDPI workaround
* Tue Nov  9 2021 Alexei Podvalsky <avvissu@yandex.by>
- Add gstreamer-plugins as recommend dependencies
* Mon Jul 22 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.0:
  * Add the debian rules back
  * Remove debian rules (makes the build falling)
  * Add validation tests
  * Remove CMake files
  * Update packaging for meson
  * Update install section in README.md
  * Switch to eson build
  * Update ru.po
  * Merge pull request #46 from eurruby/contrib
  * Add Brazilian Portuguese to Desktop File
  * fixed warnings for appdata
  * make stack_switcher.homogeneous = true;
  * fixed black window in juno
  * Update com.github.artemanufrij.screencast.appdata.xml
- Add HiDPI icons
- Spec file cleanup
* Thu Aug 16 2018 jengelh@inai.de
- Ensure neutrality of description, and adjust grammar.
* Wed Aug  1 2018 avvissu@yandex.by
- Update to 0.3.0:
  * Update appdata
- Switch to metainfo from appdata
- Remove obsolete macros
* Sat Apr  7 2018 avvissu@yandex.by
- Update to 0.2.4:
  * don't hide control window
  * removed douplicate line
  * Update README.md
  * Update lt.po
  * Serbian localization
* Sat Mar 17 2018 avvissu@yandex.by
- Update to 0.2.3:
  * fixed top margin for record controls
  * move indicator function
  * Merge pull request #31 from GitHaarek/patch-1
  * http to https and url fixes
  * pot + German
* Fri Mar  9 2018 avvissu@yandex.by
- Update to 0.2.2:
  * Update com.github.artemanufrij.screencast.appdata.xml
  * Update com.github.artemanufrij.screencast.desktop
  * Tweak the capitalisation of some sentences
  * Improve .desktop comment and generic name slightly
  * Update lt.po
  * fixed es.po
  * fix instand recording from plank
  * fixed area recording
  * Update README.md
  * new pot file
  * code style
  * removed unused this.hide ();
  * application behavior
  * small improvements
  * pause on focus
- Add appindicator dependency
* Wed Nov  8 2017 avvissu@yandex.by
- Update to 0.1.9:
  * [FIX] Don't create a subfolder on every launch
  * Recording microphone and desktop sounds at the same time
  * Updated German Translation
  * Added gschema.xml-file
- Switch from bzr to git
- Rename the package: eidete -> screencast
- Spec file cleanup
* Sat Feb 27 2016 mailaender@opensuse.org
- initial packaging (version 0.2+r201) for build.opensuse.org
